@@ -72,7 +72,7 @@ class TimeSeriesEncoder(BaseEncoder):
                     continue  # we only use group column for indexing and selecting rows
 
                 assert dep['original_type'] in (dtype.categorical, dtype.binary,
-                                                dtype.integer, dtype.float, dtype.array)
+                                                dtype.integer, dtype.float, dtype.tsarray)
 
                 if f'__mdb_ts_previous_{self.target}' == dep_name:
                     self.dep_norms[dep_name] = ts_analysis['target_normalizers']
@@ -92,7 +92,7 @@ class TimeSeriesEncoder(BaseEncoder):
                 # add descriptor size to the total encoder output dimensionality
                 if dep['original_type'] in (dtype.categorical, dtype.binary):
                     total_dims += len(self.dep_norms[dep_name]['__default'].scaler.categories_[0])
-                elif dep['original_type'] in (dtype.integer, dtype.float, dtype.array):
+                elif dep['original_type'] in (dtype.integer, dtype.float, dtype.tsarray):
                     total_dims += 1
 
         if self.encoder_class == EncoderRNNNumerical:
@@ -355,7 +355,7 @@ class TimeSeriesEncoder(BaseEncoder):
                 if dep in self.grouped_by:
                     continue
                 # normalize numerical target per group-by
-                if self._target_type in (dtype.integer, dtype.float, dtype.array):
+                if self._target_type in (dtype.integer, dtype.float, dtype.tsarray):
                     dep_info = {
                         'group_info': {group: dependency_data[group] for group in self.grouped_by},
                         'data': dep_data
