@@ -1,18 +1,18 @@
 from typing import List
-from lightwood.model.base import BaseModel
+from lightwood.mixer.base import BaseMixer
 import pandas as pd
 from lightwood.data.encoded_ds import EncodedDs
 
 
 class BaseEnsemble:
     data: List[EncodedDs]
-    models: List[BaseModel]
+    mixers: List[BaseMixer]
     best_index: int
     supports_proba: bool
 
-    def __init__(self, target, models: List[BaseModel], data: List[EncodedDs]) -> None:
+    def __init__(self, target, mixers: List[BaseMixer], data: List[EncodedDs]) -> None:
         self.data = data
-        self.models = models
+        self.mixers = mixers
         self.best_index = 0
         self.supports_proba = False
 
