@@ -10,6 +10,10 @@ class TestBasic(unittest.TestCase):
         from lightwood.api.high_level import predictor_from_problem
 
         df = pd.read_csv('tests/data/boston.csv')[:500]
+        # Mess with the names to also test if lightwood can deal /w weird names
+        df = df.rename(columns={df.columns[1]: f'\'{df.columns[1]}\''})
+        df = df.rename(columns={df.columns[2]: f'\'{df.columns[2]}}}'})
+        df = df.rename(columns={df.columns[3]: f'{{{df.columns[3]}\"'})
         target = 'MEDV'
 
         predictor = predictor_from_problem(df, ProblemDefinition.from_dict({'target': target, 'time_aim': 200}))
